#
# spec file for package ngspice
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with    oldapps

%global flavor shlibs%{nil}

%if "%flavor" == "shlibs"
%define build_shared 1
%endif
%define pname   ngspice

Name:           %pname%{?build_shared:-shared}
%define so_ver 0
Version:        43
Release:        bp160.1.7
Summary:        Mixed-level, Mixed-signal Circuit Simulator Based on spice3f5
License:        BSD-2-Clause
Group:          Productivity/Scientific/Electronics
URL:            https://ngspice.sourceforge.io
Source0:        https://downloads.sourceforge.net/%{pname}/%{pname}-%{version}.tar.gz
BuildRequires:  bison
BuildRequires:  fftw3-devel
BuildRequires:  gcc-c++
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(tinfo)
%if ! 0%{?build_shared}
BuildRequires:  libXaw-devel
BuildRequires:  libXext-devel
BuildRequires:  libXft-devel
BuildRequires:  libXmu-devel
%endif
Requires:       %{pname}-scripts = %{version}
Requires:       %{pname}-xspice-cm = %{version}
Recommends:     %{pname}-doc = %{version}

%description
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice.

%package oldapps
Summary:        Some deprecated applications included in ngspice
Group:          Productivity/Scientific/Electronics
Requires:       %{pname} = %{version}
Provides:       %{pname}:%{_bindir}/ngmakeidx

%description oldapps
Some deprecated applications formerly distributed in the main
ngspice package:
- ngmakeidx
- ngmultidec
- ngnutmeg
- ngproc2mod
- ngsconvert

%package xspice-cm
Summary:        Xspice code model Plugins
Group:          Productivity/Scientific/Electronics

%description xspice-cm
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the Xspice code model plugins.

%package scripts
Summary:        Ngspice init scripts
Group:          Productivity/Scientific/Electronics
# https://sourceforge.net/p/ngspice/bugs/615/
# BuildArch:      noarch

%description scripts
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the ngspice init scripts shared
between ngspice and libngspice.

%package -n lib%{pname}%{so_ver}
Summary:        Shared libraries for ngspice
Group:          System/Libraries
Requires:       %{pname}-scripts
Requires:       %{pname}-xspice-cm

%description -n lib%{pname}%{so_ver}
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the shared libraries.

%package -n lib%{pname}-devel
Summary:        Development files for ngspice
Group:          Development/Libraries/Other
Requires:       lib%{pname}%{so_ver} = %{version}

%description -n lib%{pname}-devel
Ngspice is a mixed-level/mixed-signal circuit simulator. Its code
is based on three open source software packages: Spice3f5, Cider1b1
and Xspice. This package contains the development files.

%prep
%setup -q -n ngspice-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%configure \
    --disable-debug \
%if 0%{?build_shared}
    --with-ngshared \
%else
    --with-x \
    %{?with_oldapps:--enable-oldapps} \
%endif
    --with-readline=yes \
    --enable-xspice \
    --enable-cider \
    --enable-openmp \
    --enable-osdi \
    --enable-predictor \
    %{nil}
%make_build

%install
%make_install
chmod -x ANALYSES AUTHORS BUGS DEVICES FAQ NEWS README

%if ! 0%{?build_shared}
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_mandir}/man1/cmpp.1*
%else
find %{buildroot} -type f -name "*.la" -delete -print
rm -rf %{buildroot}%{_includedir}/config.h
# Remove files distributed in the main package
rm -rf %{buildroot}/%{_mandir} \
       %{buildroot}%{_libdir}/%{pname} \
       %{buildroot}%{_datadir}/%{pname}/scripts
%endif

%post -n lib%{pname}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{pname}%{so_ver} -p /sbin/ldconfig

%if ! 0%{?build_shared}
%files
%license COPYING
%doc ANALYSES AUTHORS BUGS DEVICES FAQ NEWS README
%{_bindir}/ngspice
%{_mandir}/man1/ngspice.1%{?ext_man}
%dir %{_datadir}/ngspice

%if 0%{?with_oldapps}
%files oldapps
%{_bindir}/ngmakeidx
%{_bindir}/ngmultidec
%{_bindir}/ngnutmeg
%{_bindir}/ngproc2mod
%{_bindir}/ngsconvert
%{_mandir}/man1/ngmakeidx.1%{?ext_man}
%{_mandir}/man1/ngmultidec.1%{?ext_man}
%{_mandir}/man1/ngnutmeg.1%{?ext_man}
%{_mandir}/man1/ngproc2mod.1%{?ext_man}
%{_mandir}/man1/ngsconvert.1%{?ext_man}
%endif

%files scripts
%{_datadir}/ngspice/scripts

%files xspice-cm
%{_libdir}/%{pname}

%else

%files -n lib%{pname}%{so_ver}
%{_libdir}/lib%{pname}.so.*

%files -n lib%{pname}-devel
%dir %{_includedir}/%{pname}
%{_includedir}/%{pname}/sharedspice.h
%{_libdir}/lib%{pname}.so
%{_libdir}/pkgconfig/%{pname}.pc
%endif

%changelog
* Fri Aug  9 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 43:
  * Configure options KLU, OSDI, readline, OpenMP, and XSPICE have
    been defined as standard.
  * The VBIC bipolar model has bee significantly updated.
  * JFET and diode models have been updated as well.
  * Improved error message, trying to find the location of
    the error.
  * For additional new features see the included NEWS file.
* Mon Jan  1 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 42:
  * KLU matrix solver has been added to the venerable Sparse 1.3
  * Verilog-A device models (copiled by OpenVAF) now support
    small signal noise simulation.
  * Digital C coded circuit blocks may be read by the
    code model d_process.
  * Verilog (digital) circuits, compiled with Verilator,
    may be read into ngspice by new code model d_cosim.
  * For additional new features see the included NEWS file.
- Update to version 41:
  * Analog node changes in VCD file output.
  * Read Touchstone file for S parameter simulation.
  * Completely renewed XSPICE d_osc code model.
  * Updates to commands setscale, compose, eprvcd, iplot, and
    listing.
  * Option FREQ for E and G sources.
  * New dot command .libsave.
* Wed Apr  5 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 40:
  * New features:
    + VBIC: Add optional parameters for determining the operation
    region
    + VBIC: Add bvbe, bvbc, bvce, bvsub as SOA parameters
    + Add inertial delay to all basic digital code models, make it
    available for U devices
    + VDMOS default parameters are now similar to IRF540 IRF9540
    + Add function atanh to .control section
    + Add a scale factor 'a' (atto, 1e-18)
  * Bug fixes:
    + ngspice-40 is mostly a bug-fix release. In conjunction with
    KiCad and shared ngspice, inappropriate user inputs have led
    to crashing ngspice.
    + bugs no. 331, 619, 620, 624 have been fixed
    + 9 crash bugs (double delete, access NULL pointer etc)
    removed which have occurred mostly due to incomplete or
    faulty inputs.
    + Memory leaks removed
- Moved user manual (ngspice-doc) to separate source package.
* Tue Feb 14 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 39:
  * New features:
    + ngspice now offers simulation with Verilog-A models, using
    its new OSDI interface and the OpenVAF model compiler. This
    enhancement enables access to all modern compact models for
    short channel MOS, FinFets, double gate transistors, SiGe
    bipolars, and III-V HEMTs.
    + ngspice now supports nearly all features of digital PSPICE
    compatible U devices (instances). Therefore we now may
    simulate a wealth of digital devices. These are translated
    into internal XSPICE event models, with very fast simulation.
    + For a list of additional new features please have a look at
    the NEWS feature in the ngspice tarball.
  * Patches: Many developer and user provided patches and bug
    fixes have been applied.
* Fri Jan 27 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove noarch from scripts package, spinit contains absolute
  paths to binary codemodels.
- Update URL
* Sat Nov  5 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 38:
  * New features:
    + .probe command updated (current and power measurements).
    + Support of digital devices with U-instance models
    (PSPICE compatible).
    + Automatic generation of A/D and D/A bridging interfaces, when
    mixed signal simulation (combining analog and event-based
    digital) is used.
    + Update to pow() function (LTSPICE compatible).
    + For a list of all new features please have a look at the
    NEWS feature in the ngspice tarball.
  * Patches: Many developer and user provided patches and bug
    fixes have been applied.
* Sat Jun 25 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 37:
  * New features:
    + .probe command to measure currents, differential potentials
    or device power dissipation
    + S-parameter simulation with command .sp
    + command 'esave' to save only relevant digital nodes
    + substantail speed-up of plotting under MS Windows
    + flags 'alle' and 'digitop' to the plot command
    + reduce XSPICE memory consumption dramatically
    + For a list of all new features please have a look at the
    included NEWS file.
  * Patches:
    Many developer and user provided patches and bug fixes have
    been applied. Other bugs and some memory leaks have been
    removed as well.
- Remove obsolete ngspice-Use-gnuplot-terminal-auto-detection.patch
- Spec file cleanup
* Fri Feb 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 36:
  * New features:
    + .probe command to measure currents or differential potentials
    + x/y contour plots for 2d Cider simulation
    + new function integ (integration)
    + command 'wrnodev' to print matrix RHS as .ic = V(node_xx)
    + Transient operating point
    + more SOA (safe operating area) parameters on more devices
    + For a list of all new features please have a look at the
    included NEWS file.
  * Patches:
    + Many developer and user provided patches and bug fixes have
    been applied. Other bugs and some memory leaks have been
    removed as well.
* Thu Sep 23 2021 Matthew Trescott <matthewtrescott@gmail.com>
- Packaging changes:
  * Fix build dependencies to include X libs for interactive build
  * Add build dependency on Xft for FreeType rendering in plotter
* Mon Aug 16 2021 Andrés B.S. <andresbs@opensuse.org>
- Update to version 35:
  * New features:
    + Libtool version info for shared ngspice
    + Version info in sharedspice.h.
    + Replace double braces {{...}} by {(...)} in netlist (PSLT
    mode).
    + Add plotting of graphics in SVG format.
    + Setting variable 'nounits' allows suppressing the unit in a
    graph.
    + Update of macOS configure script.
    + In sharedspice API, convert all boolean variables to type
    integer for C++ compatibility.
    + Add geometry scaling to diode device model (level 3).
    + In PS mode exp function is limited to exp(14).
    + Speed enhancement for using SkyWater PDK under Linux.
    + Add option Cshunt which adds a capacitor to each circuit
    voltage node.
    + Diode device model now has a self heating option.
    + Allow opening files with names containing ANSI special
    characters.
    + Enable using parameters in .options lines.
    + For C and R devices enable value tokens like 4k7 or 1u2
    in addition to 4.7k and 1.2u.
    + New XSPICE pswitch for internally replacing the vswitch.
    + Within a single run, allow multiple PS or SVG plots with
    different names.
    + Don't replace a device model name by a parameter,
    if both have the same names.
    + Analog delay code model 'delay'.
    + B source (ASRC) will acknowledge temp and dtemp instance
    parameters.
    + In CIDER printing of either ASCII or binary is supported.
    + PSP models now support NMOS and PMOS, update to parameters
    and examples.
    + E and G source TABLE function replaces by a B source pwl.
    + re-enable making the old help system for Linux/Cygwin
    by --enable-help --enable-oldapps.
    + Enable the m parameter in E, G, B, R behavioral
    source/devices.
  * Bug fixes:
    + Many bugs fixed and code improvements (see ngspice bugs
    539 and up, at SourceForge).
    + Memory leaks removed.
* Sat Feb 20 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 34
  * New features:
    + High speed bipolar model HICUM2.4 has been added.
    + Improved compatibility with Open Source Google/Skywater PDK.
    + KiCad compliance has been improved, compatibility to PSPICE
    device models as well.
  * Various bug fixes
- Update to version 33
  * New features:
    + Further improved VDMOS power transistor model.
    + Improved JFET model (temperature model) and bipolar model
    (Krull quasi-saturation model).
    + New commands, new code models, compatibility switches for
    KiCad and Spectre have been added.
    + KiCad compliance has been improved.
  * Various bug fixes
- For details please have a look at the included NEWS file.
- Packaging changes:
  * Disable building of "oldapps", e.g. nutmeg. These are
    unmaintained and fail to build with current GCC.
  * Standalone building of XSPICE codemodels is no longer
    supported. Dropped xspice-cm-devel subpackage
* Fri May 29 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 32
  * New features:
    + Improved VDMOS power transistor model including self-heating.
    + ngspice now understands UNICODE: file and directory names as
    well as texts for labeling images may use any valid UNICODE
    character. Internally ngspice uses utf-8 string encoding and
    UTF-16 for Windows I/O.
    + The graphics output on native Windows, Postscript and X11 has
    been updated considerably, concerning color and linewidth
    selection and fonts for labeling.
    + New commands have been added.
    + Error messages have been improved, several crash scenarios
    caused by input errors have been removed.
    + For a list of all new features please have a look at the
    NEWS feature in the ngspice tarball.
  * Patches: More than 30 developer and user provided patches and
    bug fixes have been applied. Other bugs and some memory leaks
    have been removed as well.
- Rebase ngspice-Use-gnuplot-terminal-auto-detection.patch
* Wed Nov 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 31
  * Bug fixes: 6 bugs that users have reported on the ngspice bug
    tracker have been fixed. Other bugs and some memory leaks have
    been removed as well.
  * New features:
    + Improved VBIC model including self-heating
    + variable 'nostepsizelimit' to speed up certain simulations
    + new command 'setcs'
    + vectors lin-tstart, lin-tstop, and lin-tstep enable the
    'linearize' command to cut out a section of a result vector.
- Spec file cleanup
  * only BuildRequire X11 devel packages for non-library package
  * only specify really required
* Sat Jan  5 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 30
  * Bug fixes: 15 bugs that users have reported on the ngspice bug
    tracker have been fixed. Other bugs and some memory leaks have
    been removed as well.
  * New features: The VDMOS model has been overhauled and updated.
    A new variable 'controlswait' allows shifting the command
    sequence in shared ngspice to after the simulation.
  * Documentation: The manual making procedure has been setup anew.
    A html manual may be generated in addition to the pdf version.
- Update to version 29
  * Bug fixes: Small bugs fixed, lots of memory leaks removed.
  * New features: Enhanced compatibility modes with PSPICE (.include
    files or the complete netlist), LTSPICE compatibility started,
    not yet complete. New 'sidiode' simple diode model, new command
    'setseed', new internal variables 'no_auto_gnd' and 'inputdir'.
    Environmental variable SOURCE_DATE_EPOCH is supported.
  * Documentation: Updated pdf manual and other documentation.
- Update to version 28
  * License: All licenses involved are DFSG compatible.
  * Bug fixes: Small bugs fixed, memory leaks removed, code
    reorganized to improve its readability and safety.
  * New features: new VDMOS power MOS model, ngspice reads device
    libs with PSPICE syntax, old apps like ngnutmeg are made only
    upon user reqest, new commands 'mc_source' and 'alterparam',
    instance parameters may be added to the .model line, new
    variable 'sim_status', ngspice shared library supports XSPICE
    digital event data over its interface, pkg-config added .
  * Documentation: Updated pdf manual and other documentation.
- set -fPIE/-pie also on Leap 42.x/SLE12, use LDFLAGS for -pie
* Sun May  6 2018 stefan.bruens@rwth-aachen.de
- Removed shared library header from non-shared devel package
* Tue Dec  5 2017 eich@suse.com
- Build shared library version of ngspice using the multibuild
  feature.
  Building the shared library version of ngspice requires a separate
  build which doesn't build the binaries and doesn't allow to build
  with the X Window System UI.
  Also it requires the package to be split in several sub-packages:
  * a package containing most of the ngspice binaries.
  * a package containing the shared library and a development
    package for applications using the ngspice API.
  * a code model package for Xspice and a development package
    for code models.
  * a scripts package
- Added -fpie and -pie to CFLAGS to ensure position independent
  executables.
* Tue Dec  5 2017 eich@suse.com
- Update to version 27
  * check for correct inductor coefficients
  * add variable 'win_console'
  * --enable-relpath configure flag to set preprocessor flag HAS_RELPATH
  * sets search path for spinit relativ to current directory
  * The search path for .spiceinit is: current dir, HOME dir, USERPROFILE dir
  * new function stddev to calculate the standard deviation of all elements
    of a vector
  * xspice digital n-input x m-output look-up table gate
  * xspice digital model d_lut (digital n-input look-up table gate)
  * add variable $sharedmode (if shared ngspice is running), to be used in
    scripts
  * enable msys2 for mingw compilation
  * OMP support for bsim3v3.24 model
  * bsim3v3.24: add model parameter lmlt (Channel length scaling)
  * OMP support for BSIM4.5 model
  * update and extension of command 'wrdata'
  * option xmu to set damping in trapezoid integration
  * command 'linearize' will take time data from transient analysis vector if
    no circuit is loaded
  * two new commands: edisplay and eprvcd
  * 'edisplay' will show a list of all event nodes
  * 'eprvcd' will print all event nodes in vcd format
  * XSPICE 2D and 3D table models
  * add variable 'batchmode' which is set when command line option `-b' is
    active
  * enable backquote substitution for Visual Studio console apps
  * update how-to-ngspice-vstudio.txt
  * update visualc directory and project files, add XSPICE code model
    generation by VS2015
  * allow access to 4 GB memory of 32 bit ngspice on 64 bit Windows, 8 TB for
    64 bit ngspice
  * new variable `interactive'
  * xspice, introduce cm_message_printf()
  * add variable `width' to command "print line ..."
  * support msys2
  * favor exponential temperatur equation if all parameters tc1, tc2 and tce
    are given for R
  * move libfftw3 sideways out of the ngspice tree
  * remove visual studio 2008 .vcproj files
  * visualc/sharedspice.vcxproj, updated and migrated with visual studio 2015
  * `E..table {expr} {pairs}', `G..', allow an optional `=' after `table'
  * `E..value=', `G..value=', allow `=' being optional
  * introduce TCE, exponential temperature coefficient for R
  * allow `temper' to be recognised when preceded by '='
  * allow cross-compilation, especially for MinGW-w64
  * allow "plot xlog ylog" (equiv to "plot loglog")
  * extend qa test to hisimhv version 2
  * update hisimhv model to version 2.2.0
  * update hisim model to version 2.8.0
  * .control variable "sqrnoise" to deliver noise data in squared
    representation
  * noise analysis, deliver results in V/sqrt(Hz) and A/sqrt(Hz)
  * add delvt0 for bsim4 models
  * bug fixes for diode model
  * allow a xspice circuit with exclusively xspice event nodes
  * man pages for cmpp ngmakeidx and ngproc2mod
  * implement `nint()'
  * everywhere: ln to the base e, log to the base e, log10 to the base 10
  * allow an optional '=' in ".func foo() = {expr}"
  * bsim4, update to version 4.8
  * update hisimhv to version 1.2.4
  * cmc quality check for bsim3 model
  * nested indexing for vectors
  * option savecurrents to save current through all devices
  * option interp to plot interpolated raw file data
  * MS VS 2010 project file added for compatibility
  * XSPICE: new callback function cm_get_path
- ngspice-fix-warning.patch: Removed - obsolete.
- ngspice-gnuplot-terminal.patch replaced by
  ngspice-Use-gnuplot-terminal-auto-detection.patch
* Sun Jun  4 2017 malcolmlewis@opensuse.org
- Revert previous changes as this builds a shared engine only not
  executable binaries.
- Clean up spec file, fix license naming and update copyright year.
- Add verbose building with V=1.
- Add -fPIC and -fopenmp flags to Tumbleweed builds.
* Sun Mar 26 2017 xxxxxmichl@googlemail.com
- enable shared lib build
- added sub package for shared lib and devel
* Tue Jun 10 2014 dmitry_r@opensuse.org
- Update to version 26
  * fft command may use fftw3 library
  * add nint() rounding function
  * usage of 'temper' in behavioral devices
  * check for soa (safe operating area) in several device models
  * library processing rewritten completely to enhance ngspice
    compatibility (.lib)
  * include file processing rewritten to allow nesting and various
    absolute and relative path names (.inc)
  * asinh, acosh, atanh functions
  * shared ngspice option added: ngspice optionally compiles as
    a shared object or dynamic link library
  * use a hash table to massively speed up parsing the netlist
  * implement a very basic .if/.else block
  * implement a signed power function `pwr' for controlled sources
  * implement multiplier `m' in F, G source
  * apply Area Calculation Method (ACM) to the bsim3v3.3 model
  * implement `tc1', `tc2' instance parameters
- Split documentation to separate package
- Build with cider and openmp support
- Don't set gnuplot terminal, use autodetection
  * ngspice-gnuplot-terminal.patch
* Sat Apr  6 2013 werner.ho@gmx.de
- new version ngspice 25
* Wed Aug 29 2012 scorot@free.fr
- fix build for i586
- spec file reformating
* Sun Feb  5 2012 werner.ho@gmx.de
- new version ngspice 24
* Mon Jun  6 2011 Werner Hoch <werner.ho@gmx.de>
- new version 23
* Thu Oct 14 2010 Werner Hoch <werner.ho@gmx.de>
- new version 22
* Mon Jun 21 2010 Werner Hoch <werner.ho@gmx.de>
- new version 21
- removed info pages, added pdf manual
* Sun Dec 20 2009 Werner Hoch <werner.ho@gmx.de>
- new version 20
* Sun Nov 15 2009 Werner Hoch <werner.ho@gmx.de>
- packaging fix
* Tue Dec 16 2008 Werner Hoch <werner.ho@gmx.de>
- new version 18
- removed build options for older distributions
* Mon Jun 18 2007 Werner Hoch <werner.ho@gmx.de>
- added setlibpath_spinit.in.patch for x86_64
  that fixes the load of xspice codemodels
* Tue Sep 12 2006 Werner Hoch <werner.ho@gmx.de>
- enabled xspice extentions
* Wed Aug 30 2006 Werner Hoch <werner.ho@gmx.de>
- added %%%%{FORTRAN_GCC} decision
* Sun Aug 27 2006 Werner Hoch <werner.ho@gmx.de>
- first spec file
